@@ -375,13 +375,21 @@ ADD  `fixed_next_time` int(10) unsigned NOT NULL;");
                 @$db->updatequery("ALTER TABLE  `auto_ussd` ADD INDEX (  `recharge_con_type` )");
 	}
 
-/*1.23-t2*/
-	
-	@$db->updatequery("ALTER TABLE  `goip_group` ADD  `recharge_id` int(11) NOT NULL");
-	@$db->updatequery("ALTER TABLE  `goip_group` ADD  `recharge_id2` int(11) NOT NULL");
-	@$db->updatequery("ALTER TABLE  `goip_group` ADD  `recharge_cmd` varchar(32) NOT NULL");
-	@$db->updatequery("ALTER TABLE  `goip_group` ADD INDEX (  `recharge_id` )");
-	@$db->updatequery("ALTER TABLE  `goip_group` ADD INDEX (  `recharge_id2` )");
-	
+	@$db->updatequery("ALTER TABLE `message` ADD `resend` int(11) NOT NULL default '0'");
+
+/*1.24.1 fixed bug of provider with ' */
+
+	@$db->updatequery("ALTER TABLE `goip` ADD `auto_num_c` int(1) NOT NULL default '0'");
+
+/*1.24.3 fixed bug of mysql when shceduler SMS*/
+/*1.24.3 fixed bug of call expiry*/
+/*1.24.4 fixed bug of imsi when init and doapi when value=0*/
+/*1.24.4 fixed bug of receive SMS to http */
+/*1.25 add senttime in receive SMS */
+	@$db->updatequery("ALTER TABLE `receive` ADD `senttime` DATETIME NOT NULL");
+
+/*1.25 fixed bug of cron SMS and &$ in resend.php */
 	echo "update done! <a href=''  target=_top>Return</a>";
+/*1.25-t1 modify ussd timeout from 10 to 20s */
+/*1.25-t2 modify ussd timeout from 20 to 30s */
 ?>
